@@ -1,6 +1,6 @@
 """Tasks' manager for Asyncio."""
 
-__version__ = "0.22.1"
+__version__ = "0.31.0"
 __project__ = "Donald"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "BSD"
@@ -17,4 +17,10 @@ handle.setFormatter(
 )
 logger.addHandler(handle)
 
-from .manager import Donald, TaskResult, TaskWrapper  # noqa
+from threading import local
+
+current_manager = local()
+current_manager.value = None
+
+from .manager import Donald  # noqa
+from .tasks import TaskRun, TaskWrapper  # noqa
