@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from numbers import Number
 from typing import Any, Awaitable, Callable, Coroutine, Dict, Literal, Optional, Tuple, TypedDict
 
@@ -12,7 +14,7 @@ TTaskParams = TypedDict(
     },
 )
 
-TRunArgs = Tuple[Callable, Tuple, Dict[str, Any], TTaskParams]
+TRunArgs = Tuple[str, Tuple, Dict[str, Any], TTaskParams]
 
 TWorkerParams = TypedDict(
     "TWorkerParams",
